# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ...._types import Body, Query, Headers, NoneType, NotGiven, not_given
from ...._utils import maybe_transform, async_maybe_transform
from .moderator import (
    ModeratorResource,
    AsyncModeratorResource,
    ModeratorResourceWithRawResponse,
    AsyncModeratorResourceWithRawResponse,
    ModeratorResourceWithStreamingResponse,
    AsyncModeratorResourceWithStreamingResponse,
)
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.comments import v2_flag_params

__all__ = ["V2Resource", "AsyncV2Resource"]


class V2Resource(SyncAPIResource):
    @cached_property
    def moderator(self) -> ModeratorResource:
        return ModeratorResource(self._client)

    @cached_property
    def with_raw_response(self) -> V2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V2ResourceWithStreamingResponse(self)

    def delete(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/delete-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/comments/v2/{comment}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def downvote(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Downvote a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/downvote-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/comments/v2/{comment}/downvote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def flag(
        self,
        comment: str,
        *,
        reason: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Flag a comment for moderator review

        Source file: `api-server/src/controllers/comments/v2/flag-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/comments/v2/{comment}/flag",
            body=maybe_transform({"reason": reason}, v2_flag_params.V2FlagParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def toggle_endorse(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Toggle author endorsement of a comment

        Source file:
        `api-server/src/controllers/comments/v2/toggle-comment-endorse.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/comments/v2/{comment}/endorse",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def upvote(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upvote a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/upvote-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/comments/v2/{comment}/upvote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncV2Resource(AsyncAPIResource):
    @cached_property
    def moderator(self) -> AsyncModeratorResource:
        return AsyncModeratorResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV2ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV2ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV2ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV2ResourceWithStreamingResponse(self)

    async def delete(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/delete-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/comments/v2/{comment}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def downvote(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Downvote a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/downvote-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/comments/v2/{comment}/downvote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def flag(
        self,
        comment: str,
        *,
        reason: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Flag a comment for moderator review

        Source file: `api-server/src/controllers/comments/v2/flag-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/comments/v2/{comment}/flag",
            body=await async_maybe_transform({"reason": reason}, v2_flag_params.V2FlagParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def toggle_endorse(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Toggle author endorsement of a comment

        Source file:
        `api-server/src/controllers/comments/v2/toggle-comment-endorse.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/comments/v2/{comment}/endorse",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def upvote(
        self,
        comment: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Upvote a comment by UUID

        Source file:
        `api-server/src/controllers/comments/v2/upvote-comment.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not comment:
            raise ValueError(f"Expected a non-empty value for `comment` but received {comment!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/comments/v2/{comment}/upvote",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class V2ResourceWithRawResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.delete = to_raw_response_wrapper(
            v2.delete,
        )
        self.downvote = to_raw_response_wrapper(
            v2.downvote,
        )
        self.flag = to_raw_response_wrapper(
            v2.flag,
        )
        self.toggle_endorse = to_raw_response_wrapper(
            v2.toggle_endorse,
        )
        self.upvote = to_raw_response_wrapper(
            v2.upvote,
        )

    @cached_property
    def moderator(self) -> ModeratorResourceWithRawResponse:
        return ModeratorResourceWithRawResponse(self._v2.moderator)


class AsyncV2ResourceWithRawResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.delete = async_to_raw_response_wrapper(
            v2.delete,
        )
        self.downvote = async_to_raw_response_wrapper(
            v2.downvote,
        )
        self.flag = async_to_raw_response_wrapper(
            v2.flag,
        )
        self.toggle_endorse = async_to_raw_response_wrapper(
            v2.toggle_endorse,
        )
        self.upvote = async_to_raw_response_wrapper(
            v2.upvote,
        )

    @cached_property
    def moderator(self) -> AsyncModeratorResourceWithRawResponse:
        return AsyncModeratorResourceWithRawResponse(self._v2.moderator)


class V2ResourceWithStreamingResponse:
    def __init__(self, v2: V2Resource) -> None:
        self._v2 = v2

        self.delete = to_streamed_response_wrapper(
            v2.delete,
        )
        self.downvote = to_streamed_response_wrapper(
            v2.downvote,
        )
        self.flag = to_streamed_response_wrapper(
            v2.flag,
        )
        self.toggle_endorse = to_streamed_response_wrapper(
            v2.toggle_endorse,
        )
        self.upvote = to_streamed_response_wrapper(
            v2.upvote,
        )

    @cached_property
    def moderator(self) -> ModeratorResourceWithStreamingResponse:
        return ModeratorResourceWithStreamingResponse(self._v2.moderator)


class AsyncV2ResourceWithStreamingResponse:
    def __init__(self, v2: AsyncV2Resource) -> None:
        self._v2 = v2

        self.delete = async_to_streamed_response_wrapper(
            v2.delete,
        )
        self.downvote = async_to_streamed_response_wrapper(
            v2.downvote,
        )
        self.flag = async_to_streamed_response_wrapper(
            v2.flag,
        )
        self.toggle_endorse = async_to_streamed_response_wrapper(
            v2.toggle_endorse,
        )
        self.upvote = async_to_streamed_response_wrapper(
            v2.upvote,
        )

    @cached_property
    def moderator(self) -> AsyncModeratorResourceWithStreamingResponse:
        return AsyncModeratorResourceWithStreamingResponse(self._v2.moderator)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from ...._models import BaseModel

__all__ = ["ArchiveListResponse"]


class ArchiveListResponse(BaseModel):
    cursor: Optional[float] = None

    notifications: List[Optional[object]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SitemapListPapersResponse", "Data", "DataPagination", "DataPaper"]


class DataPagination(BaseModel):
    limit: float

    page: float

    total: float


class DataPaper(BaseModel):
    id: str

    universal_id: str = FieldInfo(alias="universalId")

    updated_at: str = FieldInfo(alias="updatedAt")


class Data(BaseModel):
    pagination: DataPagination

    papers: List[DataPaper]


class SitemapListPapersResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PaperGetCrxPaperInfoResponse"]


class PaperGetCrxPaperInfoResponse(BaseModel):
    has_claimed_authorship: bool = FieldInfo(alias="hasClaimedAuthorship")

    num_questions: float = FieldInfo(alias="numQuestions")

    return_version: float = FieldInfo(alias="returnVersion")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .citations import (
    CitationsResource,
    AsyncCitationsResource,
    CitationsResourceWithRawResponse,
    AsyncCitationsResourceWithRawResponse,
    CitationsResourceWithStreamingResponse,
    AsyncCitationsResourceWithStreamingResponse,
)
from .following import (
    FollowingResource,
    AsyncFollowingResource,
    FollowingResourceWithRawResponse,
    AsyncFollowingResourceWithRawResponse,
    FollowingResourceWithStreamingResponse,
    AsyncFollowingResourceWithStreamingResponse,
)
from .by_username import (
    ByUsernameResource,
    AsyncByUsernameResource,
    ByUsernameResourceWithRawResponse,
    AsyncByUsernameResourceWithRawResponse,
    ByUsernameResourceWithStreamingResponse,
    AsyncByUsernameResourceWithStreamingResponse,
)
from .semantic_scholar import (
    SemanticScholarResource,
    AsyncSemanticScholarResource,
    SemanticScholarResourceWithRawResponse,
    AsyncSemanticScholarResourceWithRawResponse,
    SemanticScholarResourceWithStreamingResponse,
    AsyncSemanticScholarResourceWithStreamingResponse,
)

__all__ = [
    "FollowingResource",
    "AsyncFollowingResource",
    "FollowingResourceWithRawResponse",
    "AsyncFollowingResourceWithRawResponse",
    "FollowingResourceWithStreamingResponse",
    "AsyncFollowingResourceWithStreamingResponse",
    "ByUsernameResource",
    "AsyncByUsernameResource",
    "ByUsernameResourceWithRawResponse",
    "AsyncByUsernameResourceWithRawResponse",
    "ByUsernameResourceWithStreamingResponse",
    "AsyncByUsernameResourceWithStreamingResponse",
    "SemanticScholarResource",
    "AsyncSemanticScholarResource",
    "SemanticScholarResourceWithRawResponse",
    "AsyncSemanticScholarResourceWithRawResponse",
    "SemanticScholarResourceWithStreamingResponse",
    "AsyncSemanticScholarResourceWithStreamingResponse",
    "CitationsResource",
    "AsyncCitationsResource",
    "CitationsResourceWithRawResponse",
    "AsyncCitationsResourceWithRawResponse",
    "CitationsResourceWithStreamingResponse",
    "AsyncCitationsResourceWithStreamingResponse",
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.papers import (
    V3LikeResponse,
    V3CommentResponse,
    V3RetrieveResponse,
    V3RetrieveAllResponse,
    V3RetrieveFeedResponse,
    V3ImplementationResponse,
    V3RequestPodcastResponse,
    V3RetrieveFiguresResponse,
    V3RetrieveMetricsResponse,
    V3RetrievePreviewResponse,
    V3RetrieveFullTextResponse,
    V3RetrieveGeoTrendsResponse,
    V3RetrieveUnrelatedResponse,
    V3PruneEmbeddingsByDateResponse,
    V3RequestImplementationResponse,
    V3RetrieveDiversePapersResponse,
    V3RetrieveSimilarPapersResponse,
    V3RetrievePapersByCountryResponse,
    V3KickoffThumbnailsTrendingPapersResponse,
)

# pyright: reportDeprecated=false

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV3:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve(
            "unresolved",
        )
        assert_matches_type(V3RetrieveResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve(
            "unresolved",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve(
            "unresolved",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `unresolved` but received ''"):
            client.papers.v3.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_comment(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        )
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_comment_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
            body="body",
            parent="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_comment(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_comment(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3CommentResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_comment(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version` but received ''"):
            client.papers.v3.with_raw_response.comment(
                version="",
                tag="anonymous",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_votes(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.delete_votes()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_votes_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.delete_votes(
            body=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_votes(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.delete_votes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_votes(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.delete_votes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_implementation(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        )
        assert_matches_type(V3ImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_implementation(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3ImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_implementation(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3ImplementationResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_implementation(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.with_raw_response.implementation(
                paper_group_id="",
                url="url",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_countries(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_paper_countries()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_countries_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_paper_countries(
            batch=1,
            max_papers=1,
            months=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_paper_countries(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.kickoff_paper_countries()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_paper_countries(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.kickoff_paper_countries() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_full_text(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_paper_full_text()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_full_text_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_paper_full_text(
            max_papers=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_paper_full_text(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.kickoff_paper_full_text()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_paper_full_text(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.kickoff_paper_full_text() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_paper_podcasts(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_paper_podcasts()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_paper_podcasts(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.kickoff_paper_podcasts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_paper_podcasts(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.kickoff_paper_podcasts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_thumbnails_trending_papers(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_thumbnails_trending_papers()
        assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_thumbnails_trending_papers(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.kickoff_thumbnails_trending_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_thumbnails_trending_papers(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.kickoff_thumbnails_trending_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_x_mentions_sync(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_x_mentions_sync()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_kickoff_x_mentions_sync_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.kickoff_x_mentions_sync(
            dry_run=True,
            limit=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_kickoff_x_mentions_sync(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.kickoff_x_mentions_sync()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_kickoff_x_mentions_sync(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.kickoff_x_mentions_sync() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_like(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3LikeResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_like(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3LikeResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_like(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3LikeResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_like(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.papers.v3.with_raw_response.like(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_podcast(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_podcast(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.v3.with_raw_response.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_podcast(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.v3.with_streaming_response.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_podcast(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
                client.papers.v3.with_raw_response.podcast(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_ai(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_ai_with_all_params(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                preferred_language="am",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_ai(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.v3.with_raw_response.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_ai(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.v3.with_streaming_response.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_process_ai(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version_id` but received ''"):
                client.papers.v3.with_raw_response.process_ai(
                    paper_version_id="",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_countries(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.process_countries(
                universal_paper_ids=["string"],
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_countries(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.v3.with_raw_response.process_countries(
                universal_paper_ids=["string"],
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_countries(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.v3.with_streaming_response.process_countries(
                universal_paper_ids=["string"],
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_process_full_text(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.process_full_text(
                paper_version_id="paperVersionId",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_process_full_text(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.v3.with_raw_response.process_full_text(
                paper_version_id="paperVersionId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_process_full_text(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.v3.with_streaming_response.process_full_text(
                paper_version_id="paperVersionId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_prune_embeddings_by_date(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = client.papers.v3.prune_embeddings_by_date()

        assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_prune_embeddings_by_date(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = client.papers.v3.with_raw_response.prune_embeddings_by_date()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_prune_embeddings_by_date(self, client: AlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with client.papers.v3.with_streaming_response.prune_embeddings_by_date() as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = response.parse()
                assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_implementation(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        )
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_implementation_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
            additional_info="additionalInfo",
        )
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_request_implementation(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_request_implementation(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_request_implementation(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.papers.v3.with_raw_response.request_implementation(
                group="",
                paper_title="paperTitle",
                universal_paper_id="universalPaperId",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_request_podcast(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_request_podcast(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_request_podcast(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_request_podcast(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.with_raw_response.request_podcast(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_all(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_all()
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_all_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_all(
            limit="limit",
            skip="skip",
        )
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_all(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_all()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_all(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_all() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_diverse_papers(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_diverse_papers(
            topics="topics",
        )
        assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_diverse_papers(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_diverse_papers(
            topics="topics",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_diverse_papers(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_diverse_papers(
            topics="topics",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_feed(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        )
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_feed_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
            exclude_seen_briefs="true",
            organizations="organizations",
            require_summary="true",
            source="GitHub",
            topics="topics",
            universal_id="universalId",
        )
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_feed(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_feed(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_figures(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_figures(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_figures(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_figures(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            client.papers.v3.with_raw_response.retrieve_figures(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_full_text(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_full_text(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_full_text(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_full_text(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version` but received ''"):
            client.papers.v3.with_raw_response.retrieve_full_text(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_geo_trends(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_geo_trends()
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_geo_trends_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_geo_trends(
            collaboration_limit="collaborationLimit",
            paper_limit="paperLimit",
            past_months="pastMonths",
            repo_limit="repoLimit",
            top_countries="topCountries",
        )
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_geo_trends(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_geo_trends()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_geo_trends(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_geo_trends() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_metrics(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_metrics(
            "unresolved",
        )
        assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_metrics(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_metrics(
            "unresolved",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_metrics(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_metrics(
            "unresolved",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_metrics(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `unresolved` but received ''"):
            client.papers.v3.with_raw_response.retrieve_metrics(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_papers_by_country(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_papers_by_country()
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_papers_by_country_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_papers_by_country(
            country="country",
            limit="limit",
        )
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_papers_by_country(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_papers_by_country()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_papers_by_country(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_papers_by_country() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_preview(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_preview(
            "id",
        )
        assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_preview(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_preview(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_preview(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_preview(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_preview(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.papers.v3.with_raw_response.retrieve_preview(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_similar_papers(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_similar_papers(
            id="id",
        )
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_similar_papers_with_all_params(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_similar_papers(
            id="id",
            exclude="exclude",
            exclude_likes="false",
            interval="3 Days",
            limit="limit",
        )
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_similar_papers(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_similar_papers(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_similar_papers(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_similar_papers(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_retrieve_similar_papers(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.papers.v3.with_raw_response.retrieve_similar_papers(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_retrieve_unrelated(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        )
        assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_retrieve_unrelated(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_retrieve_unrelated(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_view(self, client: AlphaxivCat) -> None:
        v3 = client.papers.v3.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_view(self, client: AlphaxivCat) -> None:
        response = client.papers.v3.with_raw_response.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_view(self, client: AlphaxivCat) -> None:
        with client.papers.v3.with_streaming_response.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_view(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            client.papers.v3.with_raw_response.view(
                "",
            )


class TestAsyncV3:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve(
            "unresolved",
        )
        assert_matches_type(V3RetrieveResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve(
            "unresolved",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve(
            "unresolved",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `unresolved` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_comment(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        )
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_comment_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
            body="body",
            parent="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_comment(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3CommentResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_comment(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.comment(
            version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            tag="anonymous",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3CommentResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_comment(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `version` but received ''"):
            await async_client.papers.v3.with_raw_response.comment(
                version="",
                tag="anonymous",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_votes(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.delete_votes()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_votes_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.delete_votes(
            body=["182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e"],
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_votes(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.delete_votes()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_votes(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.delete_votes() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        )
        assert_matches_type(V3ImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3ImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.implementation(
            paper_group_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            url="url",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3ImplementationResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.with_raw_response.implementation(
                paper_group_id="",
                url="url",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_countries(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_paper_countries()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_countries_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_paper_countries(
            batch=1,
            max_papers=1,
            months=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_paper_countries(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.kickoff_paper_countries()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_paper_countries(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.kickoff_paper_countries() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_paper_full_text()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_full_text_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_paper_full_text(
            max_papers=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_paper_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.kickoff_paper_full_text()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_paper_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.kickoff_paper_full_text() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_paper_podcasts(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_paper_podcasts()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_paper_podcasts(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.kickoff_paper_podcasts()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_paper_podcasts(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.kickoff_paper_podcasts() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_thumbnails_trending_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_thumbnails_trending_papers()
        assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_thumbnails_trending_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.kickoff_thumbnails_trending_papers()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_thumbnails_trending_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.kickoff_thumbnails_trending_papers() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3KickoffThumbnailsTrendingPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_x_mentions_sync(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_x_mentions_sync()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_kickoff_x_mentions_sync_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.kickoff_x_mentions_sync(
            dry_run=True,
            limit=1,
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_kickoff_x_mentions_sync(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.kickoff_x_mentions_sync()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_kickoff_x_mentions_sync(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.kickoff_x_mentions_sync() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_like(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3LikeResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_like(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3LikeResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_like(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.like(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3LikeResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_like(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.papers.v3.with_raw_response.like(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.v3.with_raw_response.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.v3.with_streaming_response.podcast(
                "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
                await async_client.papers.v3.with_raw_response.podcast(
                    "",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_ai(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_ai_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
                preferred_language="am",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_ai(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.v3.with_raw_response.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_ai(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.v3.with_streaming_response.process_ai(
                paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_process_ai(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version_id` but received ''"):
                await async_client.papers.v3.with_raw_response.process_ai(
                    paper_version_id="",
                )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_countries(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.process_countries(
                universal_paper_ids=["string"],
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_countries(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.v3.with_raw_response.process_countries(
                universal_paper_ids=["string"],
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_countries(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.v3.with_streaming_response.process_countries(
                universal_paper_ids=["string"],
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_process_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.process_full_text(
                paper_version_id="paperVersionId",
            )

        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_process_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.v3.with_raw_response.process_full_text(
                paper_version_id="paperVersionId",
            )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_process_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.v3.with_streaming_response.process_full_text(
                paper_version_id="paperVersionId",
            ) as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_prune_embeddings_by_date(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            v3 = await async_client.papers.v3.prune_embeddings_by_date()

        assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_prune_embeddings_by_date(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            response = await async_client.papers.v3.with_raw_response.prune_embeddings_by_date()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_prune_embeddings_by_date(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.warns(DeprecationWarning):
            async with async_client.papers.v3.with_streaming_response.prune_embeddings_by_date() as response:
                assert not response.is_closed
                assert response.http_request.headers.get("X-Stainless-Lang") == "python"

                v3 = await response.parse()
                assert_matches_type(V3PruneEmbeddingsByDateResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        )
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_implementation_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
            additional_info="additionalInfo",
        )
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_request_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_request_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.request_implementation(
            group="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_title="paperTitle",
            universal_paper_id="universalPaperId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RequestImplementationResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_request_implementation(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.papers.v3.with_raw_response.request_implementation(
                group="",
                paper_title="paperTitle",
                universal_paper_id="universalPaperId",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_request_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_request_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_request_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.request_podcast(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RequestPodcastResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_request_podcast(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.with_raw_response.request_podcast(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_all(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_all()
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_all_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_all(
            limit="limit",
            skip="skip",
        )
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_all(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_all()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_all(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_all() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveAllResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_diverse_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_diverse_papers(
            topics="topics",
        )
        assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_diverse_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_diverse_papers(
            topics="topics",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_diverse_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_diverse_papers(
            topics="topics",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveDiversePapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_feed(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        )
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_feed_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
            exclude_seen_briefs="true",
            organizations="organizations",
            require_summary="true",
            source="GitHub",
            topics="topics",
            universal_id="universalId",
        )
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_feed(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_feed(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_feed(
            interval="3 Days",
            page_num="pageNum",
            page_size="pageSize",
            sort="Hot",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveFeedResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_figures(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_figures(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_figures(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_figures(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveFiguresResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_figures(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_group_id` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve_figures(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_full_text(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveFullTextResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_full_text(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `paper_version` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve_full_text(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_geo_trends(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_geo_trends()
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_geo_trends_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_geo_trends(
            collaboration_limit="collaborationLimit",
            paper_limit="paperLimit",
            past_months="pastMonths",
            repo_limit="repoLimit",
            top_countries="topCountries",
        )
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_geo_trends(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_geo_trends()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_geo_trends(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_geo_trends() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveGeoTrendsResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_metrics(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_metrics(
            "unresolved",
        )
        assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_metrics(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_metrics(
            "unresolved",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_metrics(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_metrics(
            "unresolved",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveMetricsResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_metrics(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `unresolved` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve_metrics(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_papers_by_country(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_papers_by_country()
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_papers_by_country_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_papers_by_country(
            country="country",
            limit="limit",
        )
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_papers_by_country(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_papers_by_country()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_papers_by_country(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_papers_by_country() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrievePapersByCountryResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_preview(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_preview(
            "id",
        )
        assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_preview(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_preview(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_preview(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_preview(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrievePreviewResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_preview(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve_preview(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_similar_papers(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_similar_papers(
            id="id",
        )
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_similar_papers_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_similar_papers(
            id="id",
            exclude="exclude",
            exclude_likes="false",
            interval="3 Days",
            limit="limit",
        )
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_similar_papers(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_similar_papers(
            id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_similar_papers(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_similar_papers(
            id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveSimilarPapersResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_retrieve_similar_papers(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.papers.v3.with_raw_response.retrieve_similar_papers(
                id="",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_retrieve_unrelated(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        )
        assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_retrieve_unrelated(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_retrieve_unrelated(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.retrieve_unrelated(
            limit="limit",
            papers="papers",
            topics="topics",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert_matches_type(V3RetrieveUnrelatedResponse, v3, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_view(self, async_client: AsyncAlphaxivCat) -> None:
        v3 = await async_client.papers.v3.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_view(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.papers.v3.with_raw_response.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v3 = await response.parse()
        assert v3 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_view(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.papers.v3.with_streaming_response.view(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v3 = await response.parse()
            assert v3 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_view(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `group` but received ''"):
            await async_client.papers.v3.with_raw_response.view(
                "",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Literal

import httpx

from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.admin.v1 import email_send_weekly_digest_params, email_send_monthly_digest_params

__all__ = ["EmailsResource", "AsyncEmailsResource"]


class EmailsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> EmailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return EmailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> EmailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return EmailsResourceWithStreamingResponse(self)

    def send_monthly_digest(
        self,
        *,
        role: Literal["admin", "user"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Queue monthly digest emails to users via Upstash

        Source file:
        `api-server/src/controllers/admin/v1/emails/send-monthly-digest.controller.ts`

        Args:
          role: Filter by user role

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/admin/v1/emails/send-monthly-digest",
            body=maybe_transform({"role": role}, email_send_monthly_digest_params.EmailSendMonthlyDigestParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def send_weekly_digest(
        self,
        *,
        events: Iterable[email_send_weekly_digest_params.Event] | Omit = omit,
        intro_text: str | Omit = omit,
        role: Literal["admin", "user"] | Omit = omit,
        subject: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Queue weekly digest emails to users via Upstash

        Source file:
        `api-server/src/controllers/admin/v1/emails/send-weekly-digest.controller.ts`

        Args:
          events: Custom events to include

          intro_text: Custom intro message

          role: Filter by user role

          subject: Custom email subject

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            "/admin/v1/emails/send-weekly-digest",
            body=maybe_transform(
                {
                    "events": events,
                    "intro_text": intro_text,
                    "role": role,
                    "subject": subject,
                },
                email_send_weekly_digest_params.EmailSendWeeklyDigestParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncEmailsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncEmailsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncEmailsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncEmailsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncEmailsResourceWithStreamingResponse(self)

    async def send_monthly_digest(
        self,
        *,
        role: Literal["admin", "user"] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Queue monthly digest emails to users via Upstash

        Source file:
        `api-server/src/controllers/admin/v1/emails/send-monthly-digest.controller.ts`

        Args:
          role: Filter by user role

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/admin/v1/emails/send-monthly-digest",
            body=await async_maybe_transform(
                {"role": role}, email_send_monthly_digest_params.EmailSendMonthlyDigestParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def send_weekly_digest(
        self,
        *,
        events: Iterable[email_send_weekly_digest_params.Event] | Omit = omit,
        intro_text: str | Omit = omit,
        role: Literal["admin", "user"] | Omit = omit,
        subject: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Queue weekly digest emails to users via Upstash

        Source file:
        `api-server/src/controllers/admin/v1/emails/send-weekly-digest.controller.ts`

        Args:
          events: Custom events to include

          intro_text: Custom intro message

          role: Filter by user role

          subject: Custom email subject

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            "/admin/v1/emails/send-weekly-digest",
            body=await async_maybe_transform(
                {
                    "events": events,
                    "intro_text": intro_text,
                    "role": role,
                    "subject": subject,
                },
                email_send_weekly_digest_params.EmailSendWeeklyDigestParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class EmailsResourceWithRawResponse:
    def __init__(self, emails: EmailsResource) -> None:
        self._emails = emails

        self.send_monthly_digest = to_raw_response_wrapper(
            emails.send_monthly_digest,
        )
        self.send_weekly_digest = to_raw_response_wrapper(
            emails.send_weekly_digest,
        )


class AsyncEmailsResourceWithRawResponse:
    def __init__(self, emails: AsyncEmailsResource) -> None:
        self._emails = emails

        self.send_monthly_digest = async_to_raw_response_wrapper(
            emails.send_monthly_digest,
        )
        self.send_weekly_digest = async_to_raw_response_wrapper(
            emails.send_weekly_digest,
        )


class EmailsResourceWithStreamingResponse:
    def __init__(self, emails: EmailsResource) -> None:
        self._emails = emails

        self.send_monthly_digest = to_streamed_response_wrapper(
            emails.send_monthly_digest,
        )
        self.send_weekly_digest = to_streamed_response_wrapper(
            emails.send_weekly_digest,
        )


class AsyncEmailsResourceWithStreamingResponse:
    def __init__(self, emails: AsyncEmailsResource) -> None:
        self._emails = emails

        self.send_monthly_digest = async_to_streamed_response_wrapper(
            emails.send_monthly_digest,
        )
        self.send_weekly_digest = async_to_streamed_response_wrapper(
            emails.send_weekly_digest,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["V3RetrievePapersByCountryParams"]


class V3RetrievePapersByCountryParams(TypedDict, total=False):
    country: str

    limit: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["IngestIngestVersionParams"]


class IngestIngestVersionParams(TypedDict, total=False):
    upid: Required[str]

    prevent_tracking: Annotated[str, PropertyInfo(alias="preventTracking")]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from ....._models import BaseModel

__all__ = ["OrganizationListResponse", "Organization"]


class Organization(BaseModel):
    id: str

    name: str


class OrganizationListResponse(BaseModel):
    organizations: List[Organization]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V3GetLeaderboardResponse", "AllTime", "AllTimeAvatar", "Weekly", "WeeklyAvatar"]


class AllTimeAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class AllTime(BaseModel):
    id: str

    avatar: Optional[List[AllTimeAvatar]] = None

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    username: str

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")


class WeeklyAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class Weekly(BaseModel):
    id: str

    avatar: Optional[List[WeeklyAvatar]] = None

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    username: str

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")


class V3GetLeaderboardResponse(BaseModel):
    all_time: List[AllTime] = FieldInfo(alias="allTime")

    weekly: List[Weekly]
